@@ -14,3 +14,8 @@ class DBClient(object):
         self.benchmark_resource = BenchmarkDBResource(db_name="performance_test")
         self.env_resource = EnvDBResource(db_name="nodes")
         self.test_resource = TestDBResource(db_name="production_test")
+
+    def __del__(self):
+        del self.benchmark_resource
+        del self.env_resource
+        del self.test_resource
\ No newline at end of file
