@@ -1,12 +1,13 @@
 # coding=utf-8
 # pylint: disable=import-error, broad-except
 from resources.models.database import SqlConnection
-
+from resources.delete_old_data import Cleaner
 
 class BenchmarkDBResource(object):
 
     def __init__(self, db_name="performance_test"):
         self.sql = SqlConnection(db_name=db_name)
+        self.cleaner = Cleaner()
 
     def __del__(self):
         del self.sql
@@ -28,9 +29,11 @@ class BenchmarkDBResource(object):
         if test_key is not None:
             match_string = self._get_test_key_match_string(test_key)
             search_str = self._generate_filter_string(search_str, match_string, is_first_filter)
-
         return search_str
 
+    def delete_test_group(self, group_key):
+        return self.cleaner.delete_test_group(group_key)
+
     @staticmethod
     def _get_test_key_match_string(test_key):
         match_str = "`group_key`='{}'".format(test_key)
