@@ -4,9 +4,10 @@ import pymysql as mysql
 from DBUtils.PooledDB import PooledDB
 
 
-
 class SqlConnection(object):
+
     pool = dict()
+
     def __init__(self, host="172.29.129.8", port=3306, user="tester", passwd="Cnex!321", db_name="production_test"):
         self.host = host
         self.port = port
@@ -36,4 +37,15 @@ class SqlConnection(object):
             results = self.cursor.fetchall()
         except BaseException as message:
             print(message)
-        return results
\ No newline at end of file
+        return results
+
+    def execute_and_commit_sql_command(self, command):
+        results = list()
+        try:
+            self.conn.ping()
+            self.cursor.execute(command)
+            self.conn.commit()
+            results = self.cursor.fetchall()
+        except BaseException as message:
+            print(message)
+        return results
