@@ -11,6 +11,8 @@ from resources.remote_resource import RemoteResource
 from resources.benchmark_resource import BenchmarkResource
 from resources.oakgate_resource import OakgateResource
 from resources.stop_flag_resource import StopFlagResource
+from resources.git_resource import GitResource
+
 
 class RestClient(object):
 
@@ -23,3 +25,4 @@ class RestClient(object):
         self.benchmark = BenchmarkResource(host, port, __session, time_out)
         self.oakgate = OakgateResource(host, port, __session, time_out)
         self.stop_flag = StopFlagResource(host, port, __session, time_out)
+        self.git = GitResource(host, port, __session, time_out)
